summaryrefslogtreecommitdiff
path: root/CMake
diff options
context:
space:
mode:
authorLu Guanqun <guanqun.lu@intel.com>2012-12-19 11:31:42 +0800
committerZhigang Gong <zhigang.gong@linux.intel.com>2013-04-10 14:51:29 +0800
commit4ad7cad1a56463913c1763ae0ffa90df8b3d1d83 (patch)
tree043709a0971688c51b2fbe4f162e3b3b3d40c06d /CMake
parente2f07c15572653e7b403aed4ae5ba8daa617fc21 (diff)
downloadbeignet-4ad7cad1a56463913c1763ae0ffa90df8b3d1d83.tar.gz
fix compilation errors when it can't find correct library dirs
The reason is that we specify `LLVM_LIBRARY_DIRS` in `backend/src/CMakeLists.txt`, while in `FindLLVM.cmake`, we name it wrong.
Diffstat (limited to 'CMake')
-rw-r--r--CMake/FindLLVM.cmake4
1 files changed, 2 insertions, 2 deletions
diff --git a/CMake/FindLLVM.cmake b/CMake/FindLLVM.cmake
index f5a74b48..351fd762 100644
--- a/CMake/FindLLVM.cmake
+++ b/CMake/FindLLVM.cmake
@@ -1,7 +1,7 @@
# Find the native LLVM includes and library
#
# LLVM_INCLUDE_DIR - where to find llvm include files
# LLVM_LIBRARY_DIR - where to find llvm libs
# LLVM_CFLAGS - llvm compiler flags
# LLVM_LFLAGS - llvm linker flags
# LLVM_MODULE_LIBS - list of llvm libs for working with modules.
@@ -39,7 +39,7 @@ execute_process(
execute_process(
COMMAND ${LLVM_CONFIG_EXECUTABLE} --libdir
- OUTPUT_VARIABLE LLVM_LIBRARY_DIR
+ OUTPUT_VARIABLE LLVM_LIBRARY_DIRS
OUTPUT_STRIP_TRAILING_WHITESPACE
)
@@ -1,7 +1,7 @@
#
# LLVM_INCLUDE_DIR - where to find llvm include files
-# LLVM_LIBRARY_DIR - where to find llvm libs
+# LLVM_LIBRARY_DIRS - where to find llvm libs
# LLVM_CFLAGS - llvm compiler flags
# LLVM_LFLAGS - llvm linker flags